@@ -25,7 +25,7 @@ from gluonts.gluonts_tqdm import tqdm
 
 class ScaleHistogram:
     """
-    Scale histogram of a timeseries dataset
+    Scale histogram of a timeseries dataset.
 
     This counts the number of timeseries whose mean of absolute values is in
     the `[base ** i, base ** (i+1)]` range for all possible `i`.
@@ -222,7 +222,8 @@ def calculate_dataset_statistics(ts_dataset: Any) -> DatasetStatistics:
 
             assert_data_error(
                 num_feat_static_cat == len(feat_static_cat),
-                "Not all feat_static_cat vectors have the same length {} != {}.",
+                "Not all feat_static_cat vectors have the same length {}"
+                " != {}.",
                 num_feat_static_cat,
                 len(feat_static_cat),
             )
@@ -248,7 +249,8 @@ def calculate_dataset_statistics(ts_dataset: Any) -> DatasetStatistics:
 
             assert_data_error(
                 num_feat_static_real == len(feat_static_real),
-                "Not all feat_static_real vectors have the same length {} != {}.",
+                "Not all feat_static_real vectors have the same length {}"
+                " != {}.",
                 num_feat_static_real,
                 len(feat_static_real),
             )
@@ -263,11 +265,12 @@ def calculate_dataset_statistics(ts_dataset: Any) -> DatasetStatistics:
             )
 
             if feat_dynamic_cat is None:
-                # feat_dynamic_cat not found, check it was the first ts we encounter or
-                # that feat_dynamic_cat were seen before
+                # feat_dynamic_cat not found, check it was the first ts we
+                # encounter or that feat_dynamic_cat were seen before
                 assert_data_error(
                     num_feat_dynamic_cat is None or num_feat_dynamic_cat == 0,
-                    "feat_dynamic_cat was found for some instances but not others.",
+                    "feat_dynamic_cat was found for some instances but not"
+                    " others.",
                 )
                 num_feat_dynamic_cat = 0
             else:
@@ -277,23 +280,25 @@ def calculate_dataset_statistics(ts_dataset: Any) -> DatasetStatistics:
                 else:
                     assert_data_error(
                         num_feat_dynamic_cat == len(feat_dynamic_cat),
-                        "Found instances with different number of features in "
-                        "feat_dynamic_cat, found one with {} and another with {}.",
+                        "Found instances with different number of features in"
+                        " feat_dynamic_cat, found one with {} and another"
+                        " with {}.",
                         num_feat_dynamic_cat,
                         len(feat_dynamic_cat),
                     )
 
                 assert_data_error(
                     np.all(np.isfinite(feat_dynamic_cat)),
-                    "Features values have to be finite and cannot exceed single "
-                    "precision floating point range.",
+                    "Features values have to be finite and cannot exceed"
+                    " single precision floating point range.",
                 )
                 num_feat_dynamic_cat_time_steps = len(feat_dynamic_cat[0])
                 assert_data_error(
                     num_feat_dynamic_cat_time_steps == len(target),
-                    "Each feature in feat_dynamic_cat has to have the same length as "
-                    "the target. Found an instance with feat_dynamic_cat of length {} "
-                    "and a target of length {}.",
+                    "Each feature in feat_dynamic_cat has to have the same"
+                    " length as the target. Found an instance with"
+                    " feat_dynamic_cat of length {} and a target of"
+                    " length {}.",
                     num_feat_dynamic_cat_time_steps,
                     len(target),
                 )
@@ -306,12 +311,13 @@ def calculate_dataset_statistics(ts_dataset: Any) -> DatasetStatistics:
                 feat_dynamic_real = ts[FieldName.FEAT_DYNAMIC_REAL_LEGACY]
 
             if feat_dynamic_real is None:
-                # feat_dynamic_real not found, check it was the first ts we encounter or
-                # that feat_dynamic_real were seen before
+                # feat_dynamic_real not found, check it was the first ts we
+                # encounter or that feat_dynamic_real were seen before
                 assert_data_error(
                     num_feat_dynamic_real is None
                     or num_feat_dynamic_real == 0,
-                    "feat_dynamic_real was found for some instances but not others.",
+                    "feat_dynamic_real was found for some instances but not"
+                    " others.",
                 )
                 num_feat_dynamic_real = 0
             else:
@@ -321,23 +327,25 @@ def calculate_dataset_statistics(ts_dataset: Any) -> DatasetStatistics:
                 else:
                     assert_data_error(
                         num_feat_dynamic_real == len(feat_dynamic_real),
-                        "Found instances with different number of features in "
-                        "feat_dynamic_real, found one with {} and another with {}.",
+                        "Found instances with different number of features in"
+                        " feat_dynamic_real, found one with {} and another"
+                        " with {}.",
                         num_feat_dynamic_real,
                         len(feat_dynamic_real),
                     )
 
                 assert_data_error(
                     np.all(np.isfinite(feat_dynamic_real)),
-                    "Features values have to be finite and cannot exceed single "
-                    "precision floating point range.",
+                    "Features values have to be finite and cannot exceed"
+                    " single precision floating point range.",
                 )
                 num_feat_dynamic_real_time_steps = len(feat_dynamic_real[0])
                 assert_data_error(
                     num_feat_dynamic_real_time_steps == len(target),
-                    "Each feature in feat_dynamic_real has to have the same length as "
-                    "the target. Found an instance with feat_dynamic_real of length {} "
-                    "and a target of length {}.",
+                    "Each feature in feat_dynamic_real has to have the same"
+                    " length as the target. Found an instance with"
+                    " feat_dynamic_real of length {} and a target of"
+                    " length {}.",
                     num_feat_dynamic_real_time_steps,
                     len(target),
                 )
@@ -348,12 +356,14 @@ def calculate_dataset_statistics(ts_dataset: Any) -> DatasetStatistics:
                 past_feat_dynamic_real = ts[FieldName.PAST_FEAT_DYNAMIC_REAL]
 
             if past_feat_dynamic_real is None:
-                # past_feat_dynamic_real not found, check it was the first ts we encounter or
-                # that past_feat_dynamic_real were seen before
+                # past_feat_dynamic_real not found, check it was the first ts
+                # we encounter or that past_feat_dynamic_real were seen
+                # before
                 assert_data_error(
                     num_past_feat_dynamic_real is None
                     or num_past_feat_dynamic_real == 0,
-                    "past_feat_dynamic_real was found for some instances but not others.",
+                    "past_feat_dynamic_real was found for some instances but"
+                    " not others.",
                 )
                 num_past_feat_dynamic_real = 0
             else:
@@ -364,16 +374,17 @@ def calculate_dataset_statistics(ts_dataset: Any) -> DatasetStatistics:
                     assert_data_error(
                         num_past_feat_dynamic_real
                         == len(past_feat_dynamic_real),
-                        "Found instances with different number of features in "
-                        "past_feat_dynamic_real, found one with {} and another with {}.",
+                        "Found instances with different number of features in"
+                        " past_feat_dynamic_real, found one with {} and"
+                        " another with {}.",
                         num_past_feat_dynamic_real,
                         len(past_feat_dynamic_real),
                     )
 
                 assert_data_error(
                     np.all(np.isfinite(past_feat_dynamic_real)),
-                    "Features values have to be finite and cannot exceed single "
-                    "precision floating point range.",
+                    "Features values have to be finite and cannot exceed"
+                    " single precision floating point range.",
                 )
 
     assert_data_error(num_time_series > 0, "Time series dataset is empty!")
