@@ -28,7 +28,7 @@ from gluonts.dataset.loader import (
 from gluonts.dataset.stat import calculate_dataset_statistics
 from gluonts.env import env
 from gluonts.model.predictor import Predictor
-from gluonts.mx.batchify import as_in_context, batchify
+from gluonts.mx.batchify import batchify
 from gluonts.mx.distribution import DistributionOutput, StudentTOutput
 from gluonts.mx.model.estimator import GluonEstimator
 from gluonts.mx.model.predictor import RepresentableBlockPredictor
@@ -96,8 +96,8 @@ class DeepAREstimator(GluonEstimator):
         default: 'lstm')
     dropoutcell_type
         Type of dropout cells to use
-        (available: 'ZoneoutCell', 'RNNZoneoutCell', 'VariationalDropoutCell' or 'VariationalZoneoutCell';
-        default: 'ZoneoutCell')
+        (available: 'ZoneoutCell', 'RNNZoneoutCell', 'VariationalDropoutCell'
+        or 'VariationalZoneoutCell'; default: 'ZoneoutCell')
     dropout_rate
         Dropout regularization parameter (default: 0.1)
     use_feat_dynamic_real
@@ -128,8 +128,9 @@ class DeepAREstimator(GluonEstimator):
         Time features to use as inputs of the RNN (default: None, in which
         case these are automatically determined based on freq)
     num_parallel_samples
-        Number of evaluation samples per time series to increase parallelism during inference.
-        This is a model optimization that does not affect the accuracy (default: 100)
+        Number of evaluation samples per time series to increase parallelism
+        during inference. This is a model optimization that does not affect the
+        accuracy (default: 100)
     imputation_method
         One of the methods from ImputationStrategy
     train_sampler
@@ -223,7 +224,6 @@ class DeepAREstimator(GluonEstimator):
         assert alpha >= 0, "The value of `alpha` should be >= 0"
         assert beta >= 0, "The value of `beta` should be >= 0"
 
-        self.freq = freq
         self.context_length = (
             context_length if context_length is not None else prediction_length
         )
@@ -255,7 +255,7 @@ class DeepAREstimator(GluonEstimator):
         self.time_features = (
             time_features
             if time_features is not None
-            else time_features_from_frequency_str(self.freq)
+            else time_features_from_frequency_str(freq)
         )
 
         self.history_length = self.context_length + max(self.lags_seq)
@@ -407,7 +407,6 @@ class DeepAREstimator(GluonEstimator):
             transform=instance_splitter + SelectFields(input_names),
             batch_size=self.batch_size,
             stack_fn=partial(batchify, ctx=self.trainer.ctx, dtype=self.dtype),
-            decode_fn=partial(as_in_context, ctx=self.trainer.ctx),
             **kwargs,
         )
 
@@ -483,7 +482,6 @@ class DeepAREstimator(GluonEstimator):
             input_transform=transformation + prediction_splitter,
             prediction_net=prediction_network,
             batch_size=self.batch_size,
-            freq=self.freq,
             prediction_length=self.prediction_length,
             ctx=self.trainer.ctx,
             dtype=self.dtype,
