@@ -56,9 +56,10 @@ class DeepStateNetwork(mx.gluon.HybridBlock):
         self.num_cat = len(cardinality)
         self.scaling = scaling
 
-        assert len(cardinality) == len(
-            embedding_dimension
-        ), "embedding_dimension should be a list with the same size as cardinality"
+        assert len(cardinality) == len(embedding_dimension), (
+            "embedding_dimension should be a list with the same size as"
+            " cardinality"
+        )
         self.univariate = self.issm.output_dim() == 1
 
         self.noise_std_bounds = noise_std_bounds
