@@ -29,7 +29,7 @@ from gluonts.dataset.loader import (
 )
 from gluonts.env import env
 from gluonts.model.predictor import Predictor
-from gluonts.mx.batchify import as_in_context, batchify
+from gluonts.mx.batchify import batchify
 from gluonts.mx.distribution import (
     DistributionOutput,
     LowrankMultivariateGaussianOutput,
@@ -84,7 +84,7 @@ class FourierDateFeatures(TimeFeature):
         assert freq in freqs
         self.freq = freq
 
-    def __call__(self, index: pd.DatetimeIndex) -> np.ndarray:
+    def __call__(self, index: pd.PeriodIndex) -> np.ndarray:
         values = getattr(index, self.freq)
         num_values = max(values) + 1
         steps = [x * 2.0 * np.pi / num_values for x in values]
@@ -92,9 +92,6 @@ class FourierDateFeatures(TimeFeature):
 
 
 def time_features_from_frequency_str(freq_str: str) -> List[TimeFeature]:
-    offset = to_offset(freq_str)
-    granularity = norm_freq_str(offset.name)
-
     features = {
         "M": ["weekofyear"],
         "W": ["daysinmonth", "weekofyear"],
@@ -105,6 +102,8 @@ def time_features_from_frequency_str(freq_str: str) -> List[TimeFeature]:
         "T": ["minute", "hour", "dayofweek"],
     }
 
+    offset = to_offset(freq_str)
+    granularity = norm_freq_str(offset.name)
     assert granularity in features, f"freq {granularity} not supported"
 
     feature_classes: List[TimeFeature] = [
@@ -132,7 +131,7 @@ def get_lags_for_frequency(
         lags = [[1]]
 
     # use less lags
-    output_lags = list([int(lag) for sub_list in lags for lag in sub_list])
+    output_lags = list(int(lag) for sub_list in lags for lag in sub_list)
     output_lags = sorted(list(set(output_lags)))
     return output_lags[:num_lags]
 
@@ -263,7 +262,6 @@ class DeepVAREstimator(GluonEstimator):
             embedding_dimension > 0
         ), "The value of `embedding_dimension` should be > 0"
 
-        self.freq = freq
         self.context_length = (
             context_length if context_length is not None else prediction_length
         )
@@ -296,7 +294,7 @@ class DeepVAREstimator(GluonEstimator):
         self.time_features = (
             time_features
             if time_features is not None
-            else time_features_from_frequency_str(self.freq)
+            else time_features_from_frequency_str(freq)
         )
 
         self.history_length = self.context_length + max(self.lags_seq)
@@ -399,7 +397,9 @@ class DeepVAREstimator(GluonEstimator):
             else RenameFields(
                 {
                     f"past_{FieldName.TARGET}": f"past_{FieldName.TARGET}_cdf",
-                    f"future_{FieldName.TARGET}": f"future_{FieldName.TARGET}_cdf",
+                    f"future_{FieldName.TARGET}": (
+                        f"future_{FieldName.TARGET}_cdf"
+                    ),
                 }
             )
         )
@@ -417,7 +417,6 @@ class DeepVAREstimator(GluonEstimator):
             transform=instance_splitter + SelectFields(input_names),
             batch_size=self.batch_size,
             stack_fn=partial(batchify, ctx=self.trainer.ctx, dtype=self.dtype),
-            decode_fn=partial(as_in_context, ctx=self.trainer.ctx),
             **kwargs,
         )
 
@@ -481,7 +480,6 @@ class DeepVAREstimator(GluonEstimator):
             input_transform=transformation + prediction_splitter,
             prediction_net=prediction_network,
             batch_size=self.batch_size,
-            freq=self.freq,
             prediction_length=self.prediction_length,
             ctx=self.trainer.ctx,
             output_transform=self.output_transform,
