@@ -23,18 +23,17 @@ class Estimator:
     """
     An abstract class representing a trainable model.
 
-    The underlying model is trained by calling the `train` method with
-    a training `Dataset`, producing a `Predictor` object.
+    The underlying model is trained by calling the `train` method with a
+    training `Dataset`, producing a `Predictor` object.
     """
 
     __version__: str = gluonts.__version__
 
     prediction_length: int
-    freq: str
     lead_time: int
 
     def __init__(self, lead_time: int = 0, **kwargs) -> None:
-        # TODO validation of prediction_length and freq could also
+        # TODO validation of prediction_length could also
         # TODO be bubbled-up here from subclasses classes
         assert lead_time >= 0, "The value of `lead_time` should be >= 0"
 
@@ -70,7 +69,8 @@ class Estimator:
 
     @classmethod
     def from_inputs(cls, train_iter, **params):
-        # auto_params usually include `use_feat_dynamic_real`, `use_feat_static_cat` and `cardinality`
+        # auto_params usually include `use_feat_dynamic_real`,
+        # `use_feat_static_cat` and `cardinality`
         auto_params = cls.derive_auto_fields(train_iter)
         # user specified 'params' will take precedence:
         params = {**auto_params, **params}
