@@ -13,7 +13,7 @@
 
 import re
 from enum import Enum
-from typing import Callable, Dict, List, NamedTuple, Optional, Set, Union
+from typing import Callable, Dict, List, Optional, Set, Union, Tuple
 
 import numpy as np
 import pandas as pd
@@ -22,13 +22,191 @@ import pydantic
 from gluonts.core.component import validated
 from gluonts.exceptions import GluonTSUserError
 
-from .util import (
-    LinearInterpolation,
-    ExponentialTailApproximation,
-)
+
+class LinearInterpolation:
+    """
+    Linear interpolation based on datapoints (x_coord, y_coord)
+
+    Parameters
+    ----------
+    x_coord
+        x-coordinates of the data points must be in increasing order.
+    y_coord
+        y-coordinates of the data points - may be a list of lists.
+    tol
+        tolerance when performing the division in the linear interpolation.
+    """
+
+    def __init__(
+        self,
+        x_coord: List[float],
+        y_coord: List[np.ndarray],
+        tol: float = 1e-8,
+    ) -> None:
+        self.x_coord = x_coord
+        assert sorted(self.x_coord) == self.x_coord
+        self.y_coord = y_coord
+        self.num_points = len(self.x_coord)
+        assert (
+            self.num_points >= 2
+        ), "Need at least two points for linear interpolation."
+        self.tol = tol
+
+    def __call__(self, x: float):
+        return self.linear_interpolation(x)
+
+    def linear_interpolation(self, x: float) -> np.ndarray:
+        """
+        If x is out of interpolation range, return smallest or largest value.
+        Otherwise, find two nearest points [x_1, y_1], [x_2, y_2] and return
+        its linear interpolation.
+
+        y = (x_2 - x)/(x_2 - x_1) * y_1 + (x - x_1)/(x_2 - x_1) * y_2.
+
+        Parameters
+        ----------
+        x
+            x-coordinate to evaluate the interpolated points.
+
+        Returns
+        -------
+        np.ndarray
+            Interpolated values same shape as self.y_coord
+        """
+        if self.x_coord[0] >= x:
+            return self.y_coord[0]
+        elif self.x_coord[-1] <= x:
+            return self.y_coord[-1]
+        else:
+            for i, (x1, x2) in enumerate(zip(self.x_coord, self.x_coord[1:])):
+                if x1 < x < x2:
+                    denominator = x2 - x1 + self.tol
+                    return (x2 - x) / denominator * self.y_coord[i] + (
+                        x - x1
+                    ) / denominator * self.y_coord[i + 1]
 
 
-class Quantile(NamedTuple):
+class ExponentialTailApproximation:
+    """
+    Approximate function on tails based on knots and make a inference on query
+    point. Can be used for either interpolation or extrapolation on tails.
+
+    Parameters
+    ----------
+    x_coord
+        x-coordinates of the data points must be in increasing order.
+    y_coord
+        y-coordinates of the data points - may be a higher numpy array.
+    tol
+        tolerance when performing the division and computing the log in the
+        exponential extrapolation.
+    """
+
+    def __init__(
+        self,
+        x_coord: List[float],
+        y_coord: List[np.ndarray],
+        tol: float = 1e-8,
+    ) -> None:
+        self.x_coord = x_coord
+        assert sorted(self.x_coord) == self.x_coord
+        self.y_coord = y_coord
+        self.num_points = len(self.x_coord)
+        assert (
+            self.num_points >= 2
+        ), "Need at least two points for exponential approximation."
+        self.tol = tol
+        (
+            self.beta_inv_left,
+            self.beta_inv_right,
+        ) = self.init_exponential_tail_weights()
+
+    def init_exponential_tail_weights(self) -> Tuple[float, float]:
+        """
+        Initialize the weight of exponentially decaying tail functions based on
+        two extreme points on the left and right, respectively.
+
+        Returns
+        -------
+        Tuple
+            beta coefficient for left and right tails.
+        """
+        q_log_diff = np.log(
+            (self.x_coord[1] + self.tol) / (self.x_coord[0] + self.tol)
+            + self.tol
+        )
+        y_diff_left = self.y_coord[1] - self.y_coord[0]
+        beta_inv_left = y_diff_left / q_log_diff
+
+        z_log_diff = np.log(
+            (1 - self.x_coord[-2] + self.tol)
+            / (1 - self.x_coord[-1] + self.tol)
+            + self.tol
+        )  # z = 1/(1-q)
+        y_diff_right = self.y_coord[-1] - self.y_coord[-2]
+        beta_inv_right = y_diff_right / z_log_diff
+
+        return beta_inv_left, beta_inv_right
+
+    def left(self, x: float) -> np.ndarray:
+        """
+        Return the inference made on exponentially decaying tail functions.
+
+        For left tail, x = exp(beta * (q - alpha))
+        For right tail, x = 1 - exp(-beta * (q - alpha))
+
+        E.g. for x = self.x_coord[0] or self.x_coord[1], return value is
+        exactly self.y_coord[0] or self.y_coord[1], respectively.
+
+        Parameters
+        ----------
+        x
+            x-coordinate to evaluate the right tail.
+        """
+        return (
+            self.beta_inv_left
+            * np.log((x + self.tol) / (self.x_coord[1] + self.tol) + self.tol)
+        ) + self.y_coord[1]
+
+    def right(self, x: float) -> np.ndarray:
+        """
+        Return the inference made on exponentially decaying tail functions.
+
+        For left tail, x = exp(beta * (q - alpha))
+        For right tail, x = 1 - exp(-beta * (q - alpha))
+
+        E.g. for x = self.x_coord[-1] or self.x_coord[-2] ,
+        return value is exactly self.y_coord[-1]
+        or self.y_coord[-2] respectively.
+        Parameters
+        ----------
+        x
+            x-coordinate to evaluate the right tail.
+        """
+        return (
+            self.beta_inv_right
+            * np.log(
+                (1 - self.x_coord[-2] + self.tol) / (1 - x + self.tol)
+                + self.tol
+            )
+        ) + self.y_coord[-2]
+
+    def tail_range(self, default_left_tail=0.1, default_right_tail=0.9):
+        """
+        Return an effective range of left and right tails.
+        """
+        left_tail = max(
+            self.x_coord[0],
+            min(self.x_coord[1], default_left_tail),
+        )
+        right_tail = min(
+            self.x_coord[-1],
+            max(self.x_coord[-2], default_right_tail),
+        )
+        return left_tail, right_tail
+
+
+class Quantile(pydantic.BaseModel):
     value: float
     name: str
 
@@ -51,7 +229,7 @@ class Quantile(NamedTuple):
                 f"quantile value should be in [0, 1] but found {value}"
             )
 
-        return Quantile(value, name)
+        return Quantile(value=value, name=name)
 
     @classmethod
     def from_float(cls, quantile: float) -> "Quantile":
@@ -68,8 +246,8 @@ class Quantile(NamedTuple):
 
             if m is None:
                 raise GluonTSUserError(
-                    "Quantile string should be of the form "
-                    f'"p10", "p50", ... or "0.1", "0.5", ... but found {quantile}'
+                    'Quantile string should be of the form "p10", "p50", ...'
+                    f' or "0.1", "0.5", ... but found {quantile}'
                 )
             else:
                 quantile_float: float = int(m.group(1)) / 100
@@ -77,8 +255,9 @@ class Quantile(NamedTuple):
 
     @classmethod
     def parse(cls, quantile: Union["Quantile", float, str]) -> "Quantile":
-        """Produces equivalent float and string representation of a given
-        quantile level.
+        """
+        Produces equivalent float and string representation of a given quantile
+        level.
 
         >>> Quantile.parse(0.1)
         Quantile(value=0.1, name='0.1')
@@ -117,8 +296,7 @@ class Forecast:
     A abstract class representing predictions.
     """
 
-    start_date: pd.Timestamp
-    freq: str
+    start_date: pd.Period
     item_id: Optional[str]
     info: Optional[Dict]
     prediction_length: int
@@ -148,6 +326,10 @@ class Forecast:
     def median(self) -> np.ndarray:
         return self.quantile(0.5)
 
+    @property
+    def freq(self):
+        return self.start_date.freq
+
     def plot(
         self,
         prediction_intervals=(50.0, 90.0),
@@ -205,12 +387,12 @@ class Forecast:
         i_p50 = len(percentiles_sorted) // 2
 
         p50_data = ps_data[i_p50]
-        p50_series = pd.Series(data=p50_data, index=self.index)
+        p50_series = pd.Series(data=p50_data, index=self.index.to_timestamp())
         p50_series.plot(color=color, ls="-", label=f"{label_prefix}median")
 
         if show_mean:
             mean_data = np.mean(self._sorted_samples, axis=0)
-            pd.Series(data=mean_data, index=self.index).plot(
+            pd.Series(data=mean_data, index=self.index.to_timestamp()).plot(
                 color=color,
                 ls=":",
                 label=f"{label_prefix}mean",
@@ -222,7 +404,7 @@ class Forecast:
             ptile = percentiles_sorted[i]
             alpha = alpha_for_percentile(ptile)
             plt.fill_between(
-                self.index,
+                self.index.to_timestamp(),
                 ps_data[i],
                 ps_data[-i - 1],
                 facecolor=color,
@@ -231,9 +413,11 @@ class Forecast:
                 *args,
                 **kwargs,
             )
-            # Hack to create labels for the error intervals.
-            # Doesn't actually plot anything, because we only pass a single data point
-            pd.Series(data=p50_data[:1], index=self.index[:1]).plot(
+            # Hack to create labels for the error intervals. Doesn't actually
+            # plot anything, because we only pass a single data point
+            pd.Series(
+                data=p50_data[:1], index=self.index.to_timestamp()[:1]
+            ).plot(
                 color=color,
                 alpha=alpha,
                 linewidth=10,
@@ -245,10 +429,12 @@ class Forecast:
             plt.savefig(output_file)
 
     @property
-    def index(self) -> pd.DatetimeIndex:
+    def index(self) -> pd.PeriodIndex:
         if self._index is None:
-            self._index = pd.date_range(
-                self.start_date, periods=self.prediction_length, freq=self.freq
+            self._index = pd.period_range(
+                self.start_date,
+                periods=self.prediction_length,
+                freq=self.start_date.freq,
             )
         return self._index
 
@@ -314,8 +500,6 @@ class SampleForecast(Forecast):
         (num_samples, prediction_length, target_dim) (multivariate case)
     start_date
         start of the forecast
-    freq
-        forecast frequency
     info
         additional information that the forecaster may provide e.g. estimated
         parameters, number of iterations ran etc.
@@ -325,18 +509,16 @@ class SampleForecast(Forecast):
     def __init__(
         self,
         samples: np.ndarray,
-        start_date: pd.Timestamp,
-        freq: str,
+        start_date: pd.Period,
         item_id: Optional[str] = None,
         info: Optional[Dict] = None,
     ) -> None:
         assert isinstance(
             samples, np.ndarray
         ), "samples should be a numpy array"
-        assert (
-            len(np.shape(samples)) == 2 or len(np.shape(samples)) == 3
-        ), "samples should be a 2-dimensional or 3-dimensional array. Dimensions found: {}".format(
-            len(np.shape(samples))
+        assert len(np.shape(samples)) == 2 or len(np.shape(samples)) == 3, (
+            "samples should be a 2-dimensional or 3-dimensional array."
+            " Dimensions found: {}".format(len(np.shape(samples)))
         )
         self.samples = samples
         self._sorted_samples_value = None
@@ -346,13 +528,10 @@ class SampleForecast(Forecast):
         self.info = info
 
         assert isinstance(
-            start_date, pd.Timestamp
-        ), "start_date should be a pandas Timestamp object"
+            start_date, pd.Period
+        ), "start_date should be a pandas Period object"
         self.start_date = start_date
 
-        assert isinstance(freq, str), "freq should be a string"
-        self.freq = freq
-
     @property
     def _sorted_samples(self):
         if self._sorted_samples_value is None:
@@ -409,7 +588,6 @@ class SampleForecast(Forecast):
         return SampleForecast(
             samples=samples,
             start_date=self.start_date,
-            freq=self.freq,
             item_id=self.item_id,
             info=self.info,
         )
@@ -423,7 +601,6 @@ class SampleForecast(Forecast):
         return SampleForecast(
             samples=samples,
             start_date=self.start_date,
-            freq=self.freq,
             item_id=self.item_id,
             info=self.info,
         )
@@ -454,7 +631,6 @@ class SampleForecast(Forecast):
             [
                 f"SampleForecast({self.samples!r})",
                 f"{self.start_date!r}",
-                f"{self.freq!r}",
                 f"item_id={self.item_id!r}",
                 f"info={self.info!r})",
             ]
@@ -466,7 +642,6 @@ class SampleForecast(Forecast):
         return QuantileForecast(
             forecast_arrays=np.array([self.quantile(q) for q in quantiles]),
             start_date=self.start_date,
-            freq=self.freq,
             forecast_keys=quantiles,
             item_id=self.item_id,
             info=self.info,
@@ -475,7 +650,7 @@ class SampleForecast(Forecast):
 
 class QuantileForecast(Forecast):
     """
-    A Forecast that contains arrays (i.e. time series) for quantiles and mean
+    A Forecast that contains arrays (i.e. time series) for quantiles and mean.
 
     Parameters
     ----------
@@ -483,8 +658,6 @@ class QuantileForecast(Forecast):
         An array of forecasts
     start_date
         start of the forecast
-    freq
-        forecast frequency
     forecast_keys
         A list of quantiles of the form '0.1', '0.9', etc.,
         and potentially 'mean'. Each entry corresponds to one array in
@@ -497,15 +670,16 @@ class QuantileForecast(Forecast):
     def __init__(
         self,
         forecast_arrays: np.ndarray,
-        start_date: pd.Timestamp,
-        freq: str,
+        start_date: pd.Period,
         forecast_keys: List[str],
         item_id: Optional[str] = None,
         info: Optional[Dict] = None,
     ) -> None:
         self.forecast_array = forecast_arrays
-        self.start_date = pd.Timestamp(start_date, freq=freq)
-        self.freq = freq
+        assert isinstance(
+            start_date, pd.Period
+        ), "start_date should be a pandas Period object"
+        self.start_date = start_date
 
         # normalize keys
         self.forecast_keys = [
@@ -545,7 +719,8 @@ class QuantileForecast(Forecast):
         exp_tail_approximation = ExponentialTailApproximation(
             quantiles, quantile_predictions
         )
-        # The effective range of left, right tails varies over tail approximation class
+        # The effective range of left, right tails varies over tail
+        # approximation class
         (
             left_tail_quantile,
             right_tail_quantile,
@@ -577,16 +752,15 @@ class QuantileForecast(Forecast):
             ):  # 1D target. shape: (num_samples, prediction_length)
                 return 1
             else:
-                return self.forecast_array.shape[
-                    1
-                ]  # 2D target. shape: (num_samples, target_dim, prediction_length)
+                # 2D target. shape: (num_samples, target_dim,
+                # prediction_length)
+                return self.forecast_array.shape[1]
 
     def __repr__(self):
         return ", ".join(
             [
                 f"QuantileForecast({self.forecast_array!r})",
                 f"start_date={self.start_date!r}",
-                f"freq={self.freq!r}",
                 f"forecast_keys={self.forecast_keys!r}",
                 f"item_id={self.item_id!r}",
                 f"info={self.info!r})",
