@@ -43,9 +43,8 @@ AGGREGATION_METHODS = "median", "mean", "none"
 
 
 class NBEATSEnsemblePredictor(Predictor):
-    """ "
-    An ensemble predictor for N-BEATS.
-    Calling '.predict' will result in::
+    """
+    " An ensemble predictor for N-BEATS. Calling '.predict' will result in::
 
         |predictors|x|dataset|
 
@@ -57,24 +56,22 @@ class NBEATSEnsemblePredictor(Predictor):
     ----------
     prediction_length
         Prediction horizon.
-    freq
-        Frequency of the predicted data.
     predictors
-        The list of 'RepresentableBlockPredictor' that the ensemble consists of.
+        The list of 'RepresentableBlockPredictor' that the ensemble consists
+        of.
     aggregation_method
-        The method by which to aggregate the individual predictions of the models.
-        Either 'median', 'mean' or 'none', in which case no aggregation happens.
-        Default is 'median'.
+        The method by which to aggregate the individual predictions of the
+        models. Either 'median', 'mean' or 'none', in which case no aggregation
+        happens. Default is 'median'.
     """
 
     def __init__(
         self,
         prediction_length: int,
-        freq: str,
         predictors: List[RepresentableBlockPredictor],
         aggregation_method: Optional[str] = "median",
     ) -> None:
-        super().__init__(freq=freq, prediction_length=prediction_length)
+        super().__init__(prediction_length=prediction_length)
 
         assert aggregation_method in AGGREGATION_METHODS
 
@@ -100,7 +97,6 @@ class NBEATSEnsemblePredictor(Predictor):
         with (path / "parameters.json").open("w") as fp:
             parameters = dict(
                 prediction_length=self.prediction_length,
-                freq=self.freq,
                 aggregation_method=self.aggregation_method,
                 num_predictors=len(self.predictors),
             )
@@ -111,7 +107,7 @@ class NBEATSEnsemblePredictor(Predictor):
         cls, path: Path, ctx: Optional[mx.Context] = None, **kwargs
     ) -> "NBEATSEnsemblePredictor":
         """
-        Load a serialized NBEATSEnsemblePredictor from the given path
+        Load a serialized NBEATSEnsemblePredictor from the given path.
 
         Parameters
         ----------
@@ -119,7 +115,8 @@ class NBEATSEnsemblePredictor(Predictor):
             Path to the serialized files predictor.
         ctx
             Optional mxnet context parameter to be used with the predictor.
-            If nothing is passed will use the GPU if available and CPU otherwise.
+            If nothing is passed will use the GPU if available and CPU
+            otherwise.
         """
         # deserialize constructor parameters
         with (path / "parameters.json").open("r") as fp:
@@ -130,7 +127,8 @@ class NBEATSEnsemblePredictor(Predictor):
         num_digits = len(str(num_predictors))
 
         predictors = []
-        # load all the predictors individually and also make sure not to load anything else by mistake
+        # load all the predictors individually and also make sure not to load
+        # anything else by mistake
         predictor_locations = [
             f"predictor_{str(index).zfill(num_digits)}"
             for index in range(num_predictors)
@@ -144,12 +142,12 @@ class NBEATSEnsemblePredictor(Predictor):
 
         return NBEATSEnsemblePredictor(
             prediction_length=parameters["prediction_length"],
-            freq=parameters["freq"],
             predictors=predictors,
             aggregation_method=parameters["aggregation_method"],
         )
 
-    # Additionally implemented since we are dealing with RepresentableBlockPredictor
+    # Additionally implemented since we are dealing with
+    # RepresentableBlockPredictor
     def hybridize(self, batch: DataBatch) -> None:
         for predictor in self.predictors:
             predictor.hybridize(batch)
@@ -204,7 +202,6 @@ class NBEATSEnsemblePredictor(Predictor):
             yield SampleForecast(
                 output,
                 start_date=start_date,
-                freq=start_date.freqstr,
                 item_id=item[FieldName.ITEM_ID]
                 if FieldName.ITEM_ID in item
                 else None,
@@ -213,8 +210,9 @@ class NBEATSEnsemblePredictor(Predictor):
 
     def __eq__(self, that):
         """
-        Unfortunately it cannot be guaranteed that two predictors are not equal if this returns false
-        if for some reason the order of the predictors list has been altered.
+        Unfortunately it cannot be guaranteed that two predictors are not equal
+        if this returns false if for some reason the order of the predictors
+        list has been altered.
         """
         if type(self) != type(that):
             return False
@@ -222,12 +220,12 @@ class NBEATSEnsemblePredictor(Predictor):
         try:
             if not (
                 self.prediction_length == that.prediction_length
-                and self.freq == that.freq
                 and self.aggregation_method == that.aggregation_method
             ):
                 return False
         except ValueError:
-            # For example if the order of the predictors is changed we get this error
+            # For example if the order of the predictors is changed we get this
+            # error
             return False
 
         for own_predictor, that_predictor in zip(
@@ -241,12 +239,12 @@ class NBEATSEnsemblePredictor(Predictor):
 
 class NBEATSEnsembleEstimator(Estimator):
     """
-    An ensemble N-BEATS Estimator (approximately) as described
-    in the paper:  https://arxiv.org/abs/1905.10437.
+    An ensemble N-BEATS Estimator (approximately) as described in the paper:
+    https://arxiv.org/abs/1905.10437.
 
-    The three meta parameters 'meta_context_length', 'meta_loss_function' and 'meta_bagging_size'
-    together define the way the sub-models are assembled together.
-    The total number of models used for the ensemble is::
+    The three meta parameters 'meta_context_length', 'meta_loss_function'
+    and 'meta_bagging_size' together define the way the sub-models are
+    assembled together. The total number of models used for the ensemble is::
 
         |meta_context_length| x |meta_loss_function| x meta_bagging_size
 
@@ -261,17 +259,20 @@ class NBEATSEnsembleEstimator(Estimator):
     prediction_length
         Length of the prediction. Also known as 'horizon'.
     meta_context_length
-        The different 'context_length' (aslso known as 'lookback period')
+        The different 'context_length' (also known as 'lookback period')
         to use for training the models.
-        The 'context_length' is the number of time units that condition the predictions.
-        Default and recommended value: [multiplier * prediction_length for multiplier in range(2, 7)]
+        The 'context_length' is the number of time units that condition the
+        predictions. Default and recommended value:
+        [multiplier * prediction_length for multiplier in range(2, 7)]
     meta_loss_function
-        The different 'loss_function' (also known as metric) to use for training the models.
-        Unlike other models in GluonTS this network does not use a distribution.
-        Default and recommended value: ["sMAPE", "MASE", "MAPE"]
+        The different 'loss_function' (also known as metric) to use for
+        training the models. Unlike other models in GluonTS this network does
+        not use a distribution. Default and recommended value:
+        ["sMAPE", "MASE", "MAPE"]
     meta_bagging_size
-        The number of models that share the parameter combination of 'context_length'
-        and 'loss_function'. Each of these models gets a different initialization random initialization.
+        The number of models that share the parameter combination of
+        'context_length' and 'loss_function'. Each of these models gets a
+        different initialization random initialization.
         Default and recommended value: 10
     trainer
         Trainer object to be used (default: Trainer())
@@ -290,8 +291,8 @@ class NBEATSEnsembleEstimator(Estimator):
         Default and recommended value for generic mode: [4]
         Recommended value for interpretable mode: [4]
     widths
-        Widths of the fully connected layers with ReLu activation in the blocks.
-        A list of ints of length 1 or 'num_stacks'.
+        Widths of the fully connected layers with ReLu activation in the
+        blocks. A list of ints of length 1 or 'num_stacks'.
         Default and recommended value for generic mode: [512]
         Recommended value for interpretable mode: [256, 2048]
     sharing
@@ -300,15 +301,15 @@ class NBEATSEnsembleEstimator(Estimator):
         Default and recommended value for generic mode: [False]
         Recommended value for interpretable mode: [True]
     expansion_coefficient_lengths
-        If the type is "G" (generic), then the length of the expansion coefficient.
-        If type is "T" (trend), then it corresponds to the degree of the polynomial.
-        If the type is "S" (seasonal) then its not used.
+        If the type is "G" (generic), then the length of the expansion
+        coefficient. If type is "T" (trend), then it corresponds to the degree
+        of the polynomial. If the type is "S" (seasonal) then its not used.
         A list of ints of length 1 or 'num_stacks'.
         Default value for generic mode: [32]
         Recommended value for interpretable mode: [3]
     stack_types
-        One of the following values: "G" (generic), "S" (seasonal) or "T" (trend).
-        A list of strings of length 1 or 'num_stacks'.
+        One of the following values: "G" (generic), "S" (seasonal) or "T"
+        (trend). A list of strings of length 1 or 'num_stacks'.
         Default and recommended value for generic mode: ["G"]
         Recommended value for interpretable mode: ["T","S"]
     **kwargs
@@ -351,7 +352,10 @@ class NBEATSEnsembleEstimator(Estimator):
                 loss_function in VALID_LOSS_FUNCTIONS
                 for loss_function in meta_loss_function
             ]
-        ), f"Each loss function has to be one of the following: {VALID_LOSS_FUNCTIONS}."
+        ), (
+            "Each loss function has to be one of the following:"
+            f" {VALID_LOSS_FUNCTIONS}."
+        )
         assert meta_context_length is None or all(
             [context_length > 0 for context_length in meta_context_length]
         ), "The value of each `context_length` should be > 0"
@@ -392,7 +396,8 @@ class NBEATSEnsembleEstimator(Estimator):
             self.meta_loss_function,
             list(range(self.meta_bagging_size)),
         ):
-            # So far no use for the init_id, models are by default always randomly initialized
+            # So far no use for the init_id, models are by default always
+            # randomly initialized
             estimators.append(
                 NBEATSEstimator(
                     freq=self.freq,
@@ -403,7 +408,7 @@ class NBEATSEnsembleEstimator(Estimator):
                     widths=self.widths,
                     num_blocks=self.num_blocks,
                     num_block_layers=self.num_block_layers,
-                    expansion_coefficient_lengths=self.expansion_coefficient_lengths,
+                    expansion_coefficient_lengths=self.expansion_coefficient_lengths,  # noqa: E501
                     sharing=self.sharing,
                     stack_types=self.stack_types,
                     loss_function=loss_function,
@@ -420,9 +425,9 @@ class NBEATSEnsembleEstimator(Estimator):
 
         if not Model:
             raise AttributeError(
-                f"Cannot find attribute Model attached to the "
+                "Cannot find attribute Model attached to the "
                 f"{fqname_for(cls)}. Most probably you have forgotten to mark "
-                f"the class constructor as @validated()."
+                "the class constructor as @validated()."
             )
 
         try:
@@ -444,6 +449,4 @@ class NBEATSEnsembleEstimator(Estimator):
             )
             predictors.append(estimator.train(training_data, validation_data))
 
-        return NBEATSEnsemblePredictor(
-            self.prediction_length, self.freq, predictors
-        )
+        return NBEATSEnsemblePredictor(self.prediction_length, predictors)
