@@ -12,16 +12,10 @@
 # permissions and limitations under the License.
 
 from ._estimator import DeepTPPEstimator
-from ._network import DeepTPPTrainingNetwork, DeepTPPPredictionNetwork
+from ._network import DeepTPPPredictionNetwork, DeepTPPTrainingNetwork
 
 __all__ = [
     "DeepTPPEstimator",
     "DeepTPPTrainingNetwork",
     "DeepTPPPredictionNetwork",
 ]
-
-
-# fix Sphinx issues, see https://bit.ly/2K2eptM
-for item in __all__:
-    if hasattr(item, "__module__"):
-        setattr(item, "__module__", __name__)
