@@ -32,7 +32,7 @@ from gluonts.model.transformer._network import (
 )
 from gluonts.model.transformer.trans_decoder import TransformerDecoder
 from gluonts.model.transformer.trans_encoder import TransformerEncoder
-from gluonts.mx.batchify import as_in_context, batchify
+from gluonts.mx.batchify import batchify
 from gluonts.mx.distribution import DistributionOutput, StudentTOutput
 from gluonts.mx.model.estimator import GluonEstimator
 from gluonts.mx.model.predictor import RepresentableBlockPredictor
@@ -95,20 +95,20 @@ class TransformerEstimator(GluonEstimator):
         Distribution to use to evaluate observations and sample predictions
         (default: StudentTOutput())
     model_dim
-        Dimension of the transformer network, i.e., embedding dimension of the input
-        (default: 32)
+        Dimension of the transformer network, i.e., embedding dimension of the
+        input (default: 32)
     inner_ff_dim_scale
         Dimension scale of the inner hidden layer of the transformer's
         feedforward network (default: 4)
     pre_seq
-        Sequence that defined operations of the processing block before the main transformer
-        network. Available operations: 'd' for dropout, 'r' for residual connections
-        and 'n' for normalization (default: 'dn')
+        Sequence that defined operations of the processing block before the
+        main transformer network. Available operations: 'd' for dropout, 'r'
+        for residual connections and 'n' for normalization (default: 'dn')
     post_seq
-        seq
-        Sequence that defined operations of the processing block in and after the main
-        transformer network. Available operations: 'd' for dropout, 'r' for residual connections
-        and 'n' for normalization (default: 'drn').
+        Sequence that defined operations of the processing block in and after
+        the main transformer network. Available operations: 'd' for
+        dropout, 'r' for residual connections and 'n' for normalization
+        (default: 'drn').
     act_type
         Activation type of the transformer network (default: 'softrelu')
     num_heads
@@ -123,8 +123,9 @@ class TransformerEstimator(GluonEstimator):
         Time features to use as inputs of the RNN (default: None, in which
         case these are automatically determined based on freq)
     num_parallel_samples
-        Number of evaluation samples per time series to increase parallelism during inference.
-        This is a model optimization that does not affect the accuracy (default: 100)
+        Number of evaluation samples per time series to increase parallelism
+        during inference. This is a model optimization that does not affect the
+        accuracy (default: 100)
     train_sampler
         Controls the sampling of windows during training.
     validation_sampler
@@ -182,7 +183,6 @@ class TransformerEstimator(GluonEstimator):
             num_parallel_samples > 0
         ), "The value of `num_parallel_samples` should be > 0"
 
-        self.freq = freq
         self.prediction_length = prediction_length
         self.context_length = (
             context_length if context_length is not None else prediction_length
@@ -202,7 +202,7 @@ class TransformerEstimator(GluonEstimator):
         self.time_features = (
             time_features
             if time_features is not None
-            else time_features_from_frequency_str(self.freq)
+            else time_features_from_frequency_str(freq)
         )
         self.history_length = self.context_length + max(self.lags_seq)
         self.scaling = scaling
@@ -325,7 +325,6 @@ class TransformerEstimator(GluonEstimator):
             transform=instance_splitter + SelectFields(input_names),
             batch_size=self.batch_size,
             stack_fn=partial(batchify, ctx=self.trainer.ctx, dtype=self.dtype),
-            decode_fn=partial(as_in_context, ctx=self.trainer.ctx),
             **kwargs,
         )
 
@@ -385,7 +384,6 @@ class TransformerEstimator(GluonEstimator):
             input_transform=transformation + prediction_splitter,
             prediction_net=prediction_network,
             batch_size=self.batch_size,
-            freq=self.freq,
             prediction_length=self.prediction_length,
             ctx=self.trainer.ctx,
         )
