@@ -11,19 +11,15 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Standard library imports
 from typing import Optional, Tuple
 
-# Third-party imports
 import mxnet as mx
 import numpy as np
 
 from gluonts.core.component import validated
-
-# First-party imports
-from gluonts.model.common import Tensor
-from gluonts.support.linalg_util import jitter_cholesky
-from gluonts.support.util import _broadcast_param, make_nd_diag
+from gluonts.mx import Tensor
+from gluonts.mx.linalg_util import jitter_cholesky
+from gluonts.mx.util import _broadcast_param, make_nd_diag
 
 from . import Distribution, Gaussian, MultivariateGaussian
 from .distribution import getF
@@ -124,7 +120,7 @@ class LDS(Distribution):
     seq_length
         Sequence length
     F
-    """
+    """  # noqa: E501
 
     @validated()
     def __init__(
@@ -233,6 +229,13 @@ class LDS(Distribution):
         # TODO: Based on form of the prior decide to do either filtering
         #   or residual-sum-of-squares
         log_p, final_mean, final_cov = self.kalman_filter(x, observed)
+        if scale is not None:
+            F = self.F
+            # log_abs_det_jac: sum over all output dimensions.
+            ladj = -F.sum(F.log(F.abs(scale)), axis=-1, keepdims=True)
+
+            # Sum `ladj` over all time steps.
+            log_p = F.broadcast_add(log_p, ladj)
         return log_p, final_mean, final_cov
 
     def kalman_filter(
@@ -241,7 +244,6 @@ class LDS(Distribution):
         """
         Performs Kalman filtering given observations.
 
-
         Parameters
         ----------
         targets
@@ -386,10 +388,11 @@ class LDS(Distribution):
 
         # Sample the prior state.
         # samples_lat_state: (num_samples, batch_size, latent_dim, 1)
-        # The prior covariance is observed to be slightly negative definite whenever there is
-        # excessive zero padding at the beginning of the time series.
-        # We add positive tolerance to the diagonal to avoid numerical issues.
-        # Note that `jitter_cholesky` adds positive tolerance only if the decomposition without jitter fails.
+        # The prior covariance is observed to be slightly negative definite
+        # whenever there is excessive zero padding at the beginning of the time
+        # series. We add positive tolerance to the diagonal to avoid numerical
+        # issues. Note that `jitter_cholesky` adds positive tolerance only if
+        # the decomposition without jitter fails.
         state = MultivariateGaussian(
             self.prior_mean,
             jitter_cholesky(
@@ -405,7 +408,7 @@ class LDS(Distribution):
             # transition_coeff_t:
             #   (num_samples, batch_size, latent_dim, latent_dim)
             # innovation_coeff_t: (num_samples, batch_size, 1, latent_dim)
-            emission_coeff_t, transition_coeff_t, innovation_coeff_t = [
+            emission_coeff_t, transition_coeff_t, innovation_coeff_t = (
                 _broadcast_param(coeff, axes=[0], sizes=[num_samples])
                 if num_samples is not None
                 else coeff
@@ -414,7 +417,7 @@ class LDS(Distribution):
                     self.transition_coeff[t],
                     self.innovation_coeff[t],
                 ]
-            ]
+            )
 
             # Expand residuals as well
             # residual_t: (num_samples, batch_size, obs_dim, 1)
