@@ -139,7 +139,7 @@ class TransformedDistribution(Distribution):
             return s
 
     def sample_rep(
-        self, num_samples: Optional[int] = None, dtype=np.float
+        self, num_samples: Optional[int] = None, dtype=float
     ) -> Tensor:
         s = self.base_distribution.sample_rep(
             num_samples=num_samples, dtype=dtype
@@ -155,7 +155,7 @@ class TransformedDistribution(Distribution):
         for t in self.transforms[::-1]:
             x = t.f_inv(y)
             ladj = t.log_abs_det_jac(x, y)
-            lp -= sum_trailing_axes(F, ladj, self.event_dim - t.event_dim)
+            lp = lp - sum_trailing_axes(F, ladj, self.event_dim - t.event_dim)
             y = x
 
         return self.base_distribution.log_prob(x) + lp
@@ -204,33 +204,21 @@ class AffineTransformedDistribution(TransformedDistribution):
     ) -> None:
         super().__init__(base_distribution, [AffineTransformation(loc, scale)])
 
-        self.loc = loc
-        self.scale = scale
+        self.loc = loc if loc is not None else 0
+        self.scale = scale if scale is not None else 1
 
     @property
     def mean(self) -> Tensor:
-        return (
-            self.base_distribution.mean
-            if self.loc is None
-            else self.base_distribution.mean + self.loc
-        )
+        return self.base_distribution.mean * self.scale + self.loc
 
     @property
     def stddev(self) -> Tensor:
-        return (
-            self.base_distribution.stddev
-            if self.scale is None
-            else self.base_distribution.stddev * self.scale
-        )
+        return self.base_distribution.stddev * self.scale
 
     @property
     def variance(self) -> Tensor:
         # TODO: cover the multivariate case here too
-        return (
-            self.base_distribution.variance
-            if self.scale is None
-            else self.base_distribution.variance * self.scale ** 2
-        )
+        return self.base_distribution.variance * self.scale**2
 
     # TODO: crps
 
