@@ -14,14 +14,11 @@
 from typing import NamedTuple, Optional, Type
 
 import numpy as np
-from mxnet.gluon import HybridBlock
-from pydantic import ValidationError
-
 from gluonts.core import fqname_for
 from gluonts.core.component import (
+    GluonTSHyperparametersError,
     from_hyperparameters,
     validated,
-    GluonTSHyperparametersError,
 )
 from gluonts.dataset.common import Dataset
 from gluonts.dataset.loader import DataLoader
@@ -30,6 +27,8 @@ from gluonts.model.estimator import Estimator
 from gluonts.model.predictor import Predictor
 from gluonts.mx.trainer import Trainer
 from gluonts.transform import Transformation
+from mxnet.gluon import HybridBlock
+from pydantic import ValidationError
 
 
 class TrainOutput(NamedTuple):
@@ -70,9 +69,9 @@ class GluonEstimator(Estimator):
 
         if not Model:
             raise AttributeError(
-                f"Cannot find attribute Model attached to the "
+                "Cannot find attribute Model attached to the "
                 f"{fqname_for(cls)}. Most probably you have forgotten to mark "
-                f"the class constructor as @validated()."
+                "the class constructor as @validated()."
             )
 
         try:
@@ -114,6 +113,13 @@ class GluonEstimator(Estimator):
         """
         Create and return a predictor object.
 
+        Parameters
+        ----------
+        transformation
+            Transformation to be applied to data before it goes into the model.
+        module
+            A trained `HybridBlock` object.
+
         Returns
         -------
         Predictor
@@ -124,19 +130,43 @@ class GluonEstimator(Estimator):
     def create_training_data_loader(
         self, data: Dataset, **kwargs
     ) -> DataLoader:
+        """
+        Create a data loader for training purposes.
+
+        Parameters
+        ----------
+        data
+            Dataset from which to create the data loader.
+
+        Returns
+        -------
+        DataLoader
+            The data loader, i.e. and iterable over batches of data.
+        """
         raise NotImplementedError
 
     def create_validation_data_loader(
         self, data: Dataset, **kwargs
     ) -> DataLoader:
+        """
+        Create a data loader for validation purposes.
+
+        Parameters
+        ----------
+        data
+            Dataset from which to create the data loader.
+
+        Returns
+        -------
+        DataLoader
+            The data loader, i.e. and iterable over batches of data.
+        """
         raise NotImplementedError
 
     def train_model(
         self,
         training_data: Dataset,
         validation_data: Optional[Dataset] = None,
-        num_workers: Optional[int] = None,
-        num_prefetch: Optional[int] = None,
         shuffle_buffer_length: Optional[int] = None,
         cache_data: bool = False,
     ) -> TrainOutput:
@@ -148,8 +178,6 @@ class GluonEstimator(Estimator):
             transformed_training_data
             if not cache_data
             else Cached(transformed_training_data),
-            num_workers=num_workers,
-            num_prefetch=num_prefetch,
             shuffle_buffer_length=shuffle_buffer_length,
         )
 
@@ -185,8 +213,6 @@ class GluonEstimator(Estimator):
         self,
         training_data: Dataset,
         validation_data: Optional[Dataset] = None,
-        num_workers: Optional[int] = None,
-        num_prefetch: Optional[int] = None,
         shuffle_buffer_length: Optional[int] = None,
         cache_data: bool = False,
         **kwargs,
@@ -194,8 +220,6 @@ class GluonEstimator(Estimator):
         return self.train_model(
             training_data=training_data,
             validation_data=validation_data,
-            num_workers=num_workers,
-            num_prefetch=num_prefetch,
             shuffle_buffer_length=shuffle_buffer_length,
             cache_data=cache_data,
         ).predictor
