@@ -150,25 +150,29 @@ class Trainer:
         assert isinstance(batch_size, int)
 
         # TODO param disable_default_callbacks to get backwards compatibility
-        # deprecation warnings, in the future, the following callbacks should be
-        # controlled by altering callbacks:
+        # deprecation warnings, in the future, the following callbacks should
+        # be controlled by altering callbacks:
         if learning_rate_decay_factor is not None:
             warnings.warn(
-                'Trainer argument "learning_rate_decay_factor" is deprecated. Use callbacks instead.',
+                'Trainer argument "learning_rate_decay_factor" is deprecated.'
+                " Use callbacks instead.",
                 DeprecationWarning,
             )
-            assert (
-                0 <= learning_rate_decay_factor < 1
-            ), "The value of `learning_rate_decay_factor` should be in the [0, 1) range"
+            assert 0 <= learning_rate_decay_factor < 1, (
+                "The value of `learning_rate_decay_factor` should be in the"
+                " [0, 1) range"
+            )
         if patience is not None:
             warnings.warn(
-                'Trainer argument "patience" is deprecated. Use callbacks instead.',
+                'Trainer argument "patience" is deprecated. Use callbacks'
+                " instead.",
                 DeprecationWarning,
             )
             assert 0 <= patience, "The value of `patience` should be >= 0"
         if minimum_learning_rate:
             warnings.warn(
-                'Trainer argument "minimum_learning_rate" is deprecated. Use callbacks instead.',
+                'Trainer argument "minimum_learning_rate" is deprecated. Use'
+                " callbacks instead.",
                 DeprecationWarning,
             )
             assert (
@@ -272,11 +276,11 @@ class Trainer:
             def base_path() -> str:
                 return os.path.join(
                     gluonts_temp,
-                    "{}_{}".format(STATE_ARTIFACT_FILE_NAME, uuid.uuid4()),
+                    f"{STATE_ARTIFACT_FILE_NAME}_{uuid.uuid4()}",
                 )
 
             best_epoch_info = {
-                "params_path": "%s-%s.params" % (base_path(), "init"),
+                "params_path": "{}-{}.params".format(base_path(), "init"),
                 "epoch_no": -1,
                 "score": np.Inf,
             }
@@ -344,9 +348,10 @@ class Trainer:
                         )
 
                     with mx.autograd.record():
-                        # we set the mode explicitly as by default mxnet assumes
-                        # predict mode and hence dropout layers are not used if
-                        # the mode is not explicitly set to training
+                        # we set the mode explicitly as by default mxnet
+                        # assumes predict mode and hence dropout layers are
+                        # not used if the mode is not explicitly set to
+                        # training
                         mode = (
                             autograd.train_mode
                             if is_training
@@ -369,21 +374,27 @@ class Trainer:
 
                     if not np.isfinite(ndarray.sum(loss).asscalar()):
                         logger.warning(
-                            "Batch [%d] of Epoch[%d] gave NaN loss and it will be ignored",
+                            "Batch [%d] of Epoch[%d] gave NaN loss and it will"
+                            " be ignored",
                             batch_no,
                             epoch_no,
                         )
+                        should_continue = True
                     else:
                         if is_training:
                             loss.backward()
                             trainer.step(batch_size)
 
-                            self.callbacks.on_train_batch_end(
-                                training_network=net
+                            should_continue = (
+                                self.callbacks.on_train_batch_end(
+                                    training_network=net
+                                )
                             )
                         else:
-                            self.callbacks.on_validation_batch_end(
-                                training_network=net
+                            should_continue = (
+                                self.callbacks.on_validation_batch_end(
+                                    training_network=net
+                                )
                             )
 
                         epoch_loss.update(None, preds=loss)
@@ -402,65 +413,113 @@ class Trainer:
                         net_name = type(net).__name__
                         num_model_param = self.count_model_params(net)
                         logger.info(
-                            f"Number of parameters in {net_name}: {num_model_param}"
+                            f"Number of parameters in {net_name}:"
+                            f" {num_model_param}"
                         )
+                    if not should_continue:
+                        self.halt = True
+                        break
                 it.close()
 
                 # mark epoch end time and log time cost of current epoch
-                toc = time.time()
-                logger.info(
-                    "Epoch[%d] Elapsed time %.3f seconds",
-                    epoch_no,
-                    (toc - tic),
-                )
+                if not self.halt:
+                    toc = time.time()
+                    logger.info(
+                        "Epoch[%d] Elapsed time %.3f seconds",
+                        epoch_no,
+                        (toc - tic),
+                    )
 
-                logger.info(
-                    "Epoch[%d] Evaluation metric '%s'=%f",
-                    epoch_no,
-                    ("" if is_training else "validation_") + "epoch_loss",
-                    lv,
-                )
+                    logger.info(
+                        "Epoch[%d] Evaluation metric '%s'=%f",
+                        epoch_no,
+                        ("" if is_training else "validation_") + "epoch_loss",
+                        lv,
+                    )
 
                 return epoch_loss
 
             self.callbacks.on_train_start(max_epochs=self.epochs)
 
-            for epoch_no in range(self.epochs):
-                if self.halt:
-                    logger.info(f"Epoch[{epoch_no}] Interrupting training")
-                    break
+            try:
+                for epoch_no in range(self.epochs):
+                    if self.halt:
+                        logger.info(f"Epoch[{epoch_no}] Interrupting training")
+                        break
 
-                curr_lr = trainer.learning_rate
-                logger.info(f"Epoch[{epoch_no}] Learning rate is {curr_lr}")
-
-                epoch_loss = loop(
-                    epoch_no,
-                    train_iter,
-                    num_batches_to_use=self.num_batches_per_epoch,
-                )
-
-                should_continue = self.callbacks.on_train_epoch_end(
-                    epoch_no=epoch_no,
-                    epoch_loss=loss_value(epoch_loss),
-                    training_network=net,
-                    trainer=trainer,
-                )
-
-                if is_validation_available:
-                    epoch_loss = loop(
-                        epoch_no, validation_iter, is_training=False
+                    curr_lr = trainer.learning_rate
+                    logger.info(
+                        f"Epoch[{epoch_no}] Learning rate is {curr_lr}"
                     )
 
+                    epoch_loss = loop(
+                        epoch_no,
+                        train_iter,
+                        num_batches_to_use=self.num_batches_per_epoch,
+                    )
+
+                    should_continue = self.callbacks.on_train_epoch_end(
+                        epoch_no=epoch_no,
+                        epoch_loss=loss_value(epoch_loss),
+                        training_network=net,
+                        trainer=trainer,
+                    )
+
+                    if is_validation_available:
+                        epoch_loss = loop(
+                            epoch_no, validation_iter, is_training=False
+                        )
+
+                        should_continue = (
+                            should_continue
+                            and self.callbacks.on_validation_epoch_end(
+                                epoch_no=epoch_no,
+                                epoch_loss=loss_value(epoch_loss),
+                                training_network=net,
+                                trainer=trainer,
+                            )
+                        )
+
+                    # save model and epoch info
+                    bp = base_path()
+                    epoch_info = {
+                        "params_path": f"{bp}-0000.params",
+                        "epoch_no": epoch_no,
+                        "score": loss_value(epoch_loss),
+                    }
+
+                    net.save_parameters(
+                        epoch_info["params_path"]
+                    )  # TODO: handle possible exception
+
+                    save_epoch_info(bp, epoch_info)
+
+                    # update best epoch info
+                    if loss_value(epoch_loss) < cast(
+                        float, best_epoch_info["score"]
+                    ):
+                        best_epoch_info = epoch_info.copy()
+
                     should_continue = (
                         should_continue
-                        and self.callbacks.on_validation_epoch_end(
+                        and self.callbacks.on_epoch_end(
                             epoch_no=epoch_no,
                             epoch_loss=loss_value(epoch_loss),
                             training_network=net,
                             trainer=trainer,
+                            best_epoch_info=best_epoch_info,
+                            ctx=self.ctx,
                         )
                     )
 
+                    if not should_continue:
+                        logger.info("Stopping training")
+                        break
+            except KeyboardInterrupt:
+                warnings.warn(
+                    "Detected KeyboardInterrupt, attempting graceful "
+                    "shutdown..."
+                )
                 # save model and epoch info
                 bp = base_path()
                 epoch_info = {
@@ -469,34 +528,9 @@ class Trainer:
                     "score": loss_value(epoch_loss),
                 }
 
-                net.save_parameters(
-                    epoch_info["params_path"]
-                )  # TODO: handle possible exception
-
+                net.save_parameters(epoch_info["params_path"])
                 save_epoch_info(bp, epoch_info)
 
-                # update best epoch info
-                if loss_value(epoch_loss) < cast(
-                    float, best_epoch_info["score"]
-                ):
-                    best_epoch_info = epoch_info.copy()
-
-                should_continue = (
-                    should_continue
-                    and self.callbacks.on_epoch_end(
-                        epoch_no=epoch_no,
-                        epoch_loss=loss_value(epoch_loss),
-                        training_network=net,
-                        trainer=trainer,
-                        best_epoch_info=best_epoch_info,
-                        ctx=self.ctx,
-                    )
-                )
-
-                if not should_continue:
-                    logger.info("Stopping training")
-                    break
-
             self.callbacks.on_train_end(
                 training_network=net,
                 temporary_dir=gluonts_temp,
