@@ -15,8 +15,9 @@ import numpy as np
 
 
 def thinning_sampler(rng, lamb, xmin=0, lamb_min=1e-10):
-    """Ogata's Thinning algorithm for time-varying exponential distribution
-    with monotone-decreasing intensity function
+    """
+    Ogata's Thinning algorithm for time-varying exponential distribution with
+    monotone-decreasing intensity function.
     """
     while lamb(xmin) > lamb_min:
         dx = -np.log(rng.rand()) / lamb(xmin)
@@ -32,7 +33,9 @@ def thinning_sampler(rng, lamb, xmin=0, lamb_min=1e-10):
 
 
 def Hawkes(rng, background, kernel, xmin, xmax, N_max=1e6):
-    """requires int x kernel(x)<infty"""
+    """
+    requires int x kernel(x)<infty.
+    """
     X = []
     while len(X) < N_max:
         lamb = lambda x: background + np.sum(  # noqa
