@@ -272,7 +272,8 @@ class GluonTSFramework(Framework):
         image_uri: str = None,
         **kwargs,
     ) -> GluonTSModel:
-        """Create a ``GluonTSModel`` object that can be deployed to an
+        """
+        Create a ``GluonTSModel`` object that can be deployed to an
         ``Endpoint``.
 
         Parameters
@@ -395,7 +396,7 @@ class GluonTSFramework(Framework):
     ):
         """
         Convert the job description to init params that can be handled by the
-        class constructor
+        class constructor.
 
         Parameters
         ----------
@@ -446,8 +447,8 @@ class GluonTSFramework(Framework):
 
         if self.code_location is None:
             code_bucket, _ = parse_s3_url(self.output_path)
-            self.code_location = (
-                f"s3://{code_bucket}"  # for consistency with sagemaker API
+            self.code_location = (  # for consistency with sagemaker API
+                f"s3://{code_bucket}"
             )
 
         locations = Locations(
@@ -609,9 +610,10 @@ class GluonTSFramework(Framework):
         **kwargs,
     ) -> Tuple[Framework, str]:
         """
-        Use this function to run a custom script specified in 'entry_point' in GluonTSFramework.
-        To access files on s3 specify them in inputs. If you want to access local files you should
-        have specified them in 'dependencies' in GluonTSFramework.
+        Use this function to run a custom script specified in 'entry_point' in
+        GluonTSFramework. To access files on s3 specify them in inputs. If you
+        want to access local files you should have specified them in
+        'dependencies' in GluonTSFramework.
 
         Parameters
         ----------
