@@ -25,11 +25,13 @@ from ._base import (
     MinuteOfHourIndex,
     MonthOfYear,
     MonthOfYearIndex,
-    norm_freq_str,
-    time_features_from_frequency_str,
+    SecondOfMinute,
+    SecondOfMinuteIndex,
     TimeFeature,
     WeekOfYear,
     WeekOfYearIndex,
+    norm_freq_str,
+    time_features_from_frequency_str,
 )
 from .holiday import SPECIAL_DATE_FEATURES, SpecialDateFeatureSet
 from .lag import get_lags_for_frequency
@@ -51,6 +53,8 @@ __all__ = [
     "MinuteOfHourIndex",
     "MonthOfYear",
     "MonthOfYearIndex",
+    "SecondOfMinute",
+    "SecondOfMinuteIndex",
     "norm_freq_str",
     "SPECIAL_DATE_FEATURES",
     "SpecialDateFeatureSet",
