@@ -11,54 +11,19 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-from functools import lru_cache
 from typing import Iterator, List, Optional
 
 import numpy as np
-import pandas as pd
+from pandas.tseries.offsets import BaseOffset
 
 from gluonts.core.component import validated
 from gluonts.dataset.common import DataEntry
 from gluonts.dataset.field_names import FieldName
-from gluonts.exceptions import GluonTSDateBoundsError
 
 from ._base import FlatMapTransformation
 from .sampler import ContinuousTimePointSampler, InstanceSampler
 
 
-def shift_timestamp(ts: pd.Timestamp, offset: int) -> pd.Timestamp:
-    """
-    Computes a shifted timestamp.
-
-    Basic wrapping around pandas ``ts + offset`` with caching and exception
-    handling.
-    """
-    return _shift_timestamp_helper(ts, ts.freq, offset)
-
-
-@lru_cache(maxsize=10000)
-def _shift_timestamp_helper(
-    ts: pd.Timestamp, freq: str, offset: int
-) -> pd.Timestamp:
-    """
-    We are using this helper function which explicitly uses the frequency as a
-    parameter, because the frequency is not included in the hash of a time
-    stamp.
-
-    I.e.
-      pd.Timestamp(x, freq='1D')  and pd.Timestamp(x, freq='1min')
-
-    hash to the same value.
-    """
-    try:
-        # this line looks innocent, but can create a date which is out of
-        # bounds values over year 9999 raise a ValueError
-        # values over 2262-04-11 raise a pandas OutOfBoundsDatetime
-        return ts + offset * freq
-    except (ValueError, pd._libs.OutOfBoundsDatetime) as ex:
-        raise GluonTSDateBoundsError(ex) from ex
-
-
 class InstanceSplitter(FlatMapTransformation):
     """
     Selects training instances, by slicing the target and other time series
@@ -195,18 +160,15 @@ class InstanceSplitter(FlatMapTransformation):
                     ].transpose()
 
             d[self._past(self.is_pad_field)] = pad_indicator
-            d[self.forecast_start_field] = shift_timestamp(
-                d[self.start_field], i + lt
-            )
+            d[self.forecast_start_field] = d[self.start_field] + i + lt
             yield d
 
 
 class CanonicalInstanceSplitter(FlatMapTransformation):
     """
-    Selects instances, by slicing the target and other time series
-    like arrays at random points in training mode or at the last time point in
-    prediction mode. Assumption is that all time like arrays start at the same
-    time point.
+    Selects instances, by slicing the target and other time series like arrays
+    at random points in training mode or at the last time point in prediction
+    mode. Assumption is that all time like arrays start at the same time point.
 
     In training mode, the returned instances contain past_`target_field`
     as well as past_`time_series_fields`.
@@ -313,8 +275,8 @@ class CanonicalInstanceSplitter(FlatMapTransformation):
             pad_length = max(self.instance_length - i, 0)
 
             # update start field
-            d[self.start_field] = shift_timestamp(
-                data[self.start_field], i - self.instance_length
+            d[self.start_field] = (
+                data[self.start_field] + i - self.instance_length
             )
 
             # set is_pad field
@@ -353,8 +315,8 @@ class CanonicalInstanceSplitter(FlatMapTransformation):
 
                 del d[ts_field]
 
-            d[self.forecast_start_field] = shift_timestamp(
-                d[self.start_field], self.instance_length
+            d[self.forecast_start_field] = (
+                d[self.start_field] + self.instance_length
             )
 
             yield d
@@ -363,10 +325,10 @@ class CanonicalInstanceSplitter(FlatMapTransformation):
 class ContinuousTimeInstanceSplitter(FlatMapTransformation):
     """
     Selects training instances by slicing "intervals" from a continous-time
-    process instantiation. Concretely, the input data is expected to describe an
-    instantiation from a point (or jump) process, with the "target"
-    identifying inter-arrival times and other features (marks), as described
-    in detail below.
+    process instantiation. Concretely, the input data is expected to describe
+    an instantiation from a point (or jump) process, with the "target"
+    identifying inter-arrival times and other features (marks), as described in
+    detail below.
 
     The splitter will then take random points in continuous time from each
     given observation, and return a (variable-length) array of points in
@@ -378,17 +340,18 @@ class ContinuousTimeInstanceSplitter(FlatMapTransformation):
     - It does not allow "incomplete" records. That is, the past and future
       intervals sampled are always complete
     - Outputs a (T, C) layout.
-    - Does not accept `time_series_fields` (i.e., only accepts target fields) as these
-      would typically not be available in TPP data.
+    - Does not accept `time_series_fields` (i.e., only accepts target fields)
+      as these would typically not be available in TPP data.
 
     The target arrays are expected to have (2, T) layout where the first axis
     corresponds to the (i) interarrival times between consecutive points, in
-    order and (ii) integer identifiers of marks (from {0, 1, ..., :code:`num_marks`}).
-    The returned arrays will have (T, 2) layout.
+    order and (ii) integer identifiers of marks (from
+    {0, 1, ..., :code:`num_marks`}). The returned arrays will have (T, 2)
+    layout.
 
-    For example, the array below corresponds to a target array where points with timestamps
-    0.5, 1.1, and 1.5 were observed belonging to categories (marks) 3, 1 and 0
-    respectively: :code:`[[0.5, 0.6, 0.4], [3, 1, 0]]`.
+    For example, the array below corresponds to a target array where points
+    with timestamps 0.5, 1.1, and 1.5 were observed belonging to categories
+    (marks) 3, 1 and 0 respectively: :code:`[[0.5, 0.6, 0.4], [3, 1, 0]]`.
 
     Parameters
     ----------
@@ -413,6 +376,7 @@ class ContinuousTimeInstanceSplitter(FlatMapTransformation):
         self,
         past_interval_length: float,
         future_interval_length: float,
+        freq: BaseOffset,
         instance_sampler: ContinuousTimePointSampler,
         target_field: str = FieldName.TARGET,
         start_field: str = FieldName.START,
@@ -432,6 +396,7 @@ class ContinuousTimeInstanceSplitter(FlatMapTransformation):
         self.start_field = start_field
         self.end_field = end_field
         self.forecast_start_field = forecast_start_field
+        self.freq = freq
 
     # noinspection PyMethodMayBeStatic
     def _mask_sorted(self, a: np.ndarray, lb: float, ub: float):
@@ -443,11 +408,9 @@ class ContinuousTimeInstanceSplitter(FlatMapTransformation):
         self, data: DataEntry, is_train: bool
     ) -> Iterator[DataEntry]:
 
-        assert data[self.start_field].freq == data[self.end_field].freq
-
         total_interval_length = (
             data[self.end_field] - data[self.start_field]
-        ) / data[self.start_field].freq.delta
+        ) / self.freq
 
         sampling_times = self.instance_sampler(total_interval_length)
 
@@ -488,9 +451,12 @@ class ContinuousTimeInstanceSplitter(FlatMapTransformation):
 
             r["past_valid_length"] = np.array([len(past_mask)])
 
+            print(data[self.start_field])
+            print(future_start)
+            print(self.freq)
+
             r[self.forecast_start_field] = (
-                data[self.start_field]
-                + data[self.start_field].freq.delta * future_start
+                data[self.start_field] + self.freq.delta * future_start
             )
 
             if is_train:  # include the future only if is_train
@@ -509,6 +475,6 @@ class ContinuousTimeInstanceSplitter(FlatMapTransformation):
                 r["future_valid_length"] = np.array([len(future_mask)])
 
             # include other fields
-            r.update(keep_cols.copy())
+            r.update(keep_cols)
 
             yield r
