@@ -20,15 +20,14 @@ from gluonts.dataset.common import Dataset, ProcessStartField
     "freq, expected, given",
     [
         ("B", "2019-11-01", "2019-11-01 12:34:56"),
-        ("W", "2019-11-03", pd.Timestamp("2019-11-01 12:34:56")),
+        ("W", "2019-11-03", "2019-11-01 12:34:56"),
         ("M", "2019-11-30", "2019-11-01 12:34:56"),
-        ("12M", "2019-11-30", pd.Timestamp("2019-11-01 12:34:56")),
+        ("12M", "2019-11-30", "2019-11-01 12:34:56"),
         ("A-DEC", "2019-12-31", "2019-11-01 12:34:56"),
     ],
 )
 def test_process_start_field(freq, expected, given):
-    process = ProcessStartField.process
-    assert process(given, freq) == pd.Timestamp(expected, freq)
+    assert pd.Period(given, freq) == pd.Period(expected, freq)
 
 
 def test_dataset_instance():
